﻿
Imports NationalInstruments.NI4882

Module D200GPIBsub

    Private GpibDevice As Device            'NationalInstruments.Common.Device
    Private ibStatus As GpibStatus          'NationalInstruments.NI4882.GpibStatus
    Private clr As Board
    Private errcheck As Integer = 0

    '--------------------------------------------------------------------------------------
    ' GPIB通信部分
    '--------------------------------------------------------------------------------------
#Region " D200シリーズGPIB接続チェック関数"

    Public Function fncPORT_CHECK(ByVal iAddress As Integer) As Boolean
        Dim check As Boolean = False
        Dim message As String = " "
        Try
            GpibDevice.Write("*IDN?" & vbCr & vbLf)
            message = GpibDevice.ReadString()

            If Microsoft.VisualBasic.Left(message, 9) = "SURUGA,D2" Then
                check = True
            End If

        Catch ex As Exception
            errcheck = errcheck + 1

            check = False
            If errcheck <= 1 Then
                MsgBox("GPIBアドレス" & iAddress & vbLf & "D200シリーズコントローラ未接続")
            End If

            Exit Try

        Finally
        End Try

        If check = True Then
            errcheck = 0
        End If

        Return check

    End Function
#End Region

#Region " GPIBポートオープン関数　fncPORT_OPEN(iAddress as Integer)"
    Public Function fncPORT_OPEN(ByVal iAddress As Integer) As Boolean
        Dim portopen As Boolean

        Try
            GpibDevice = New Device(CInt(0), CByte(iAddress), CByte(0))
            portopen = True
        Catch ex As Exception
            portopen = False
            Return portopen
            Exit Try
        Finally

        End Try
        portopen = fncPORT_CHECK(iAddress)
        Return portopen
    End Function
#End Region

#Region " GPIBポートクローズ関数　fncPORT_CLOSE()"
    Public Function fncPORT_CLOSE() As Integer
        Try
            GpibDevice.Dispose()
        Catch ex As Exception
            MessageBox.Show(ex.Message)
        End Try
    End Function
#End Region

#Region " コマンド送信関数  fncSendString(strSendMessage As String)"
    Public Function fncSendString(ByVal strSendMessage As String) As Boolean
        Dim sndCommand As String
        Dim portopen As Boolean

        sndCommand = strSendMessage & vbCr & vbLf   '送信するコマンドにデリミタ[CR,LF]を付加する
        Try
            GpibDevice.Write(sndCommand)            'GPIBコマンド送信
            portopen = True                         '戻り値用フラグを立てる(ポートが開いた状態)

        Catch ex As Exception                       'エラー判別。以下、エラー時の処理
            portopen = False                        '戻り値用フラグを下ろす(GPIBエラーの場合)
            MessageBox.Show(ex.Message)             '送信エラー時、エラーメッセージをダイアログボックスで表示する
            Exit Try
        Finally

        End Try

        Return portopen

    End Function
#End Region

#Region " コマンド受信関数　fncReceiveString() as String"
    Public Function fncReceiveString() As String
        Dim message As String = "GPIBエラー"
        Try

            message = GpibDevice.ReadString()   'GPIB受信
        Catch ex As Exception                   'エラー判別。以下、エラー時の処理
            MessageBox.Show(ex.Message)         '受信エラー時、エラーメッセージをダイアログボックスで表示する
            Exit Try
        Finally

        End Try
        Return message
    End Function
#End Region


    '--------------------------------------------------------------------------------------
    ' コントローラステータスチェック部分
    '--------------------------------------------------------------------------------------
#Region " 座標取得　fncGetPosition(iAxis As Integer) As String"
    Public Function fncGetPosition(ByVal iAxis As Integer) As String
        Dim message As String = "GPIBエラー"

        If fncSendString("Axis" & iAxis & ":Position?") = True Then     ' 座標取得コマンドを送信する
            message = fncReceiveString()                                ' 座標取得

        End If

        Return message
    End Function
#End Region

#Region " コントローラステータス検出関数　fncUpdateStatus(iAxis As Integer) As String"
    Public Function fncUpdateStatus(ByVal iAxis As Integer) As String
        Dim intStatus As Integer
        Dim message As String = "GPIBエラー"

        Try

            Call fncSendString("Axis" & iAxis & ":SB3?")    ' ステータス３をコントローラへ要求する
            intStatus = Val(fncReceiveString())             ' 受信したステータスを数値に変換する

            If (intStatus And &H1) <> &H1 Then              ' ステータス３のビット１を検査する
                message = "軸選択不可能"                     ' ビット１がＯＦＦなら軸選択不可能
                fncSendString("Stop 0")                     ' 停止
            Else

                fncSendString("Axis" & iAxis & ":SB1?")     ' ステータス１をコントローラへ要求する
                intStatus = Val(fncReceiveString())         ' 受信したステータスを数値に変換する

                If (intStatus And &H40) = &H40 Then         ' ステータス３のビット１を検査する
                    message = "動作中"                       ' ビット７がＯＮなら動作中
                ElseIf (intStatus And &H10) = &H10 Then     ' ステータス１のビット５を検査する
                    message = "原点検出"                     ' ビット５がＯＮなら原点を検出している

                ElseIf (intStatus And &H2) = &H2 Then       ' ステータス1のビット２を検査する
                    fncSendString("Axis" & iAxis & ":SB2?") ' ステータス２をコントローラへ要求する
                    intStatus = Val(fncReceiveString())     ' 受信したステータスを数値に変換する

                    If (intStatus And &H3) = 3 Then         ' ステータス２のビット１，２を検査する
                        message = "ステージ未接続"           ' ビット１，２がＯＮならステージは未接続
                    ElseIf (intStatus And &H1) = &H1 Then
                        message = "ＣＷリミット検出"         ' ビット１がＯＮならＣＷリミットを検出している
                        fncSendString("Stop 0")             ' 停止
                    ElseIf (intStatus And &H2) = &H2 Then
                        message = "ＣＣＷリミット検出"       ' ビット２がＯＮならＣＣＷリミットを検出している
                        fncSendString("Stop 0")             ' 停止
                    ElseIf (intStatus And &H4) = &H4 Then
                        message = "CWソフトリミット検出"     ' ビット３がＯＮならＣＷソフトウェアリミットを検出している
                        fncSendString("Stop 0")             ' 停止
                    ElseIf (intStatus And &H8) = &H8 Then
                        message = "CCWソフトリミット検出"    ' ビット４がＯＮならＣＣＷソフトウェアリミットを検出している
                        fncSendString("Stop 0")             ' 停止
                    End If

                Else
                    message = "停止"                        ' 全てのビットがＯＦＦなら停止している
                    fncSendString("Stop 0")                 ' 停止
                End If
            End If


        Catch ex As Exception
            message = "GPIBエラー"
        End Try


        Return message
    End Function
#End Region

#Region " 入力値チェック関数　fncCheckData(TextBox, Long (Low), Long(High)) as Boolean"
    Public Function fncCheckData(ByVal txtTextbox As TextBox, _
                                   Optional ByVal lngLow As Long = 0, _
                                   Optional ByVal lngHigh As Long = 999999) As Boolean
        fncCheckData = False

        If Val(txtTextbox.Text) >= lngLow And Val(txtTextbox.Text) <= lngHigh Then
            fncCheckData = True                           ' 入力値をチェックし範囲内ならばTrueを返して終了
            Exit Function
        End If

        txtTextbox.Focus()                                  ' 値に誤りがある箇所をアクティブにする
        txtTextbox.SelectionStart = 0                       ' 先頭の文字から選択を開始
        txtTextbox.SelectionLength = Len(txtTextbox.Text)   ' テキストの最後まで選択する
    End Function

#End Region



End Module
